@@ -47,6 +47,12 @@ except (StonerAssertionError, ImportError):  # Fail if blist not present or Pyth
 _asteval_interp = None
 
 
+def _parse_date(string: str) -> datetime.datetime:
+    """Run the dateutil parser with a UK sensible date order."""
+    parserinfo = parser.parserinfo(dayfirst=True)
+    return parser.parse(string, parserinfo)
+
+
 def literal_eval(string: str) -> Any:
     """Use the asteval module to interpret arbitary strings slightly safely.
 
@@ -99,7 +105,7 @@ def string_to_type(value: String_Types) -> Any:
             if value.lower() in ["true", "yes", "on", "false", "no", "off"]:
                 ret = value.lower() in ["true", "yes", "on"]  # Boolean
             else:
-                for trial in [int, float, parser.parse, str]:
+                for trial in [int, float, _parse_date, str]:
                     try:
                         ret = trial(value)
                         break
@@ -441,12 +447,21 @@ class typeHintedDict(regexpDict):
                         ret = ""
                     break
                 elif issubclass(valuetype, datetime.datetime):
-                    ret = literal_eval(value)
-                    if isinstance(ret, string_types):
+                    if isinstance(ret, datetime.datetime):
+                        break  # Alreadu a datetime object
+                    try:
+                        ret = literal_eval(value)
+                    except ValueError:
+                        ret = str(ret)
+                    if isinstance(ret, datetime.datetime):
+                        break  # Got us a datetime object now
+                    elif isinstance(ret, string_types):  # try parsing as a string now
                         try:
-                            ret = parser.parse(ret)
+                            ret = _parse_date(ret)
+                            break
                         except (ValueError, OverflowError):
-                            pass
+                            pass  # fall back
+                    ret = datetime.datetime(1970, 1, 1)  # unparsable time
                     break
                 else:
                     ret = valuetype(value)
@@ -454,7 +469,7 @@ class typeHintedDict(regexpDict):
         else:
             ret = str(value)
             try:
-                ret = parser.parse(ret)
+                ret = _parse_date(ret)
             except (ValueError, OverflowError):
                 pass
         return ret
@@ -522,10 +537,7 @@ class typeHintedDict(regexpDict):
                 super().__setitem__(name, "")
                 self._typehints[name] = "String"
             else:
-                try:
-                    super().__setitem__(name, self.__mungevalue(typehint, value))
-                except ValueError:
-                    pass  # Silently fail
+                super().__setitem__(name, self.__mungevalue(typehint, value))
         else:
             if isinstance(value, string_types):
                 value = string_to_type(value)
