@@ -1,19 +1,17 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""
-setas module provides the setas class for DataFile and friends
-"""
+"""setas module provides the setas class for DataFile and friends."""
 __all__ = ["setas"]
 import re
 import copy
-import numpy as _np_
+from collections.abc import MutableMapping, Mapping
+
+import numpy as np
 
 from ..compat import string_types, int_types, index_types, _pattern_type
-from ..tools import _attribute_store, isiterable, typedList, islike_list
+from ..tools import AttributeStore, isiterable, typedList, isLikeList
 from .utils import decode_string
 
-from collections import MutableMapping, Mapping
-
 
 class setas(MutableMapping):
 
@@ -22,7 +20,8 @@ class setas(MutableMapping):
     Implements a MutableMapping bsed on the column_headers as the keys (with a few tweaks!).
 
     Note:
-        Iterating over setas will return the column assignments rather than the standard mapping behaviour of iterating over the keys. Otherwise
+        Iterating over setas will return the column assignments rather than the standard mapping behaviour of
+        iterating over the keys. Otherwise
         the interface is essentially as a Mapping class.
 
     Calling an existing setas instance and the constructor share the same signatgure:
@@ -41,7 +40,7 @@ class setas(MutableMapping):
     """
 
     def __init__(self, row=False, bless=None):
-        """Constructs the setas instance and sets an initial value.
+        """Construct the setas instance and sets an initial value.
 
         Args:
             ref (DataFile): Contains a reference to the owning DataFile instance
@@ -50,7 +49,7 @@ class setas(MutableMapping):
             initial_val (string or list or dict): Initial values to set
         """
         self._row = row
-        self._cols = _attribute_store()
+        self._cols = AttributeStore()
         self._shape = tuple()
         self._setas = list()
         self._column_headers = typedList(string_types)
@@ -130,11 +129,6 @@ class setas(MutableMapping):
                 if reset:
                     self.setas = []
                 value = decode_string(value)
-            elif isinstance(value, setas):
-                if value is not self:
-                    value = value.setas
-                else:
-                    value = self._setas
         else:
             value = kargs
             if reset:
@@ -168,7 +162,7 @@ class setas(MutableMapping):
     @property
     def clone(self):
         """Create an exact copy of the current object."""
-        cls = self.__class__
+        cls = type(self)
         new = cls()
         for attr in self.__dict__:
             if not callable(self.__dict__[attr]):
@@ -183,7 +177,8 @@ class setas(MutableMapping):
 
     @property
     def x(self):
-        """Quick access to the x column number
+        """Quick access to the x column number.
+
         Just a convenience read only property. If we want to change the setas.x
         value we should use the setas(x=1,y=2) style call (so that reset can
         be handled properly)
@@ -192,50 +187,60 @@ class setas(MutableMapping):
 
     @property
     def y(self):
-        """Quick access to the y column numbers list"""
+        """Quick access to the y column numbers list."""
         return self.cols["ycol"]
 
     @property
     def z(self):
-        """Quick access to the z column numbers list"""
+        """Quick access to the z column numbers list."""
         return self.cols["zcol"]
 
     @property
     def column_headers(self):
         """Get the current column headers."""
-        c = self._size
-        l = len(self._column_headers)
-        if l < c:  # Extend the column headers if necessary
-            self._column_headers.extend(["Column {}".format(i + l) for i in range(c - l)])
+        cols = self._size
+        length = len(self._column_headers)
+        if length < cols:  # Extend the column headers if necessary
+            self._column_headers.extend([f"Column {i + length}" for i in range(cols - length)])
         return self._column_headers
 
     @column_headers.setter
     def column_headers(self, value):
         """Set the colum headers."""
-        if isinstance(value, _np_.ndarray):  # Convert ndarray to list of strings
+        if isinstance(value, np.ndarray):  # Convert ndarray to list of strings
             value = value.astype(str).tolist()
         elif isinstance(value, string_types):  # Bare strings get turned into lists
             value = [value]
         self._column_headers = typedList(string_types, value)
 
+    @property
+    def empty(self):
+        """Determine if any columns are set."""
+        return len(self._setas) == 0 or np.all(np.array(self._setas) == ".")
+
+    @property
+    def ndim(self):
+        """Return the number of dimensions of the array."""
+        return len(self.shape)
+
     @property
     def not_set(self):
         """Return a boolean array if not set."""
-        return _np_.array([x == "." for x in self._setas])
+        return np.array([x == "." for x in self._setas])
 
     @property
     def set(self):
         """Return a boolean array if column is set."""
-        return ~self.not_set
+        return np.array([x != "." for x in self._setas])
 
     @property
     def setas(self):
         """Guard the setas attribute."""
-        c = self._size
-        l = len(self._setas)
-        if c > l:
-            self._setas.extend(["."] * (c - l))
-        self._setas = self._setas[:c]
+        cols = self._size
+        length = len(self._setas)
+        if cols > length:
+            self._setas.extend(["."] * (cols - length))
+        self._setas = self._setas[:cols]
         return self._setas
 
     @setas.setter
@@ -255,7 +260,7 @@ class setas(MutableMapping):
         if 0 <= len(value) <= 2:
             self._shape = tuple(value)
         else:
-            raise AttributeError("shape attribute should be a 2-tuple not a {}-tuple".format(len(value)))
+            raise AttributeError(f"shape attribute should be a 2-tuple not a {value}-tuple")
 
     def __call__(self, *args, **kargs):
         """Treat the current instance as a callable object and assign columns accordingly.
@@ -269,12 +274,12 @@ class setas(MutableMapping):
         Keyword Arguments:
             _self (bool):
                 If True, make the call return a copy of the setas object, if False, return _object attribute, if None,
-                return None
+                return None. Default - **False**
             reset (bool):
-                If False then preserve the existing set columns and simply add the new ones. Otherwise, clear all column
-                assignments before setting new ones (default).
+                If False then preserve the existing set columns and simply add the new ones. Otherwise, clear
+                all column assignments before setting new ones (default).
         """
-        return_self = kargs.pop("_self", None)
+        return_self = kargs.pop("_self", False)
         if not (args or kargs):  # New - bare call to setas will return the current value.
             return self.setas
         if len(args) == 1 and isinstance(args[0], setas):
@@ -282,9 +287,7 @@ class setas(MutableMapping):
             args[0] = args[0].to_list()
         if len(args) == 1 and not (isinstance(args[0], string_types + (setas,)) or isiterable(args[0])):
             raise SyntaxError(
-                "setas should be called with eother a string, iterable object or setas object, not a {}".format(
-                    type(args[0])
-                )
+                f"setas should be called with eother a string, iterable object or setas object, not a {type(args[0])}"
             )
 
         # If reset is neither in kargs nor a False boolean, then clear the existing setas assignments
@@ -304,9 +307,7 @@ class setas(MutableMapping):
                     k = self.find_col(k)
                     self._setas[k] = v
                 else:
-                    raise IndexError(
-                        "Unable to workout what do with {}:{} when setting the setas attribute.".format(k, v)
-                    )
+                    raise IndexError(f"Unable to workout what do with {k}:{v} when setting the setas attribute.")
         elif isiterable(value):
             if len(value) > self._size:
                 value = value[: self._size]
@@ -316,7 +317,7 @@ class setas(MutableMapping):
             value = value[: self._size]
             for i, v in enumerate(value):
                 if v.lower() not in "xyzedfuvw.-":
-                    raise ValueError("Set as column element is invalid: {}".format(v))
+                    raise ValueError(f"Set as column element is invalid: {v}")
                 if v != "-":
                     self.setas[i] = v.lower()
         else:
@@ -324,10 +325,9 @@ class setas(MutableMapping):
         self.cols.update(self._get_cols())
         if return_self is None:
             return None
-        elif return_self:
+        if return_self:
             return self
-        else:
-            return self._object
+        return self._object
 
     def __contains__(self, item):
         """Use getitem to test for membership. Either column assignments or column index types are tested."""
@@ -344,7 +344,7 @@ class setas(MutableMapping):
         self.unset(name)
 
     def __eq__(self, other):
-        """Checks to see if this is the same object, or has the same headers and the same setas values."""
+        """Check to see if this is the same object, or has the same headers and the same setas values."""
         ret = False
         if isinstance(other, string_types):  # Expand strings and convert to list
             other = [c for c in decode_string(other)]
@@ -357,9 +357,8 @@ class setas(MutableMapping):
                     if o != m:  # Look for mis-matched assignments
                         return False
                 return True
-            else:  # If other is longer then we can't matchj
-                return False
-        elif id(self) == id(other):
+            return False
+        if id(self) == id(other):
             ret = True
         else:
             ret = self.column_headers == other.column_headers and self.setas == other.setas
@@ -369,7 +368,7 @@ class setas(MutableMapping):
         """Try to see if attribute name is a key in self.cols and return that instead."""
         if name != "_cols" and name in self._cols:
             return self._cols[name]
-        return getattr(super(setas, self), name)
+        return getattr(super(), name)
 
     def __getitem__(self, name):
         """Permit the setas attribute to be treated like either a list or a dictionary.
@@ -406,7 +405,7 @@ class setas(MutableMapping):
         elif isiterable(name):
             ret = [self[x] for x in name]
         else:
-            raise IndexError("{} was not found in the setas attribute.".format(name))
+            raise IndexError(f"{name} was not found in the setas attribute.")
         return ret
 
     def __iter__(self):
@@ -414,7 +413,8 @@ class setas(MutableMapping):
 
         .. warn::
 
-            This class does not follow standard Mapping semantics - iterating iterates over the values and not the items.
+            This class does not follow standard Mapping semantics - iterating iterates over the values and not
+            the items.
         """
         _ = self.setas  # Force setas to fix size
         for c in self._setas:
@@ -433,8 +433,8 @@ class setas(MutableMapping):
                 a single letter string in the set above.
             value (integer or column index): See above.
         """
-        if islike_list(name):  # Sipport indexing with a list like object
-            if islike_list(value) and len(value) == len(name):
+        if isLikeList(name):  # Sipport indexing with a list like object
+            if isLikeList(value) and len(value) == len(name):
                 for n, v in zip(name, value):
                     self._setas[n] = v
             else:
@@ -451,6 +451,8 @@ class setas(MutableMapping):
         ):
             for c in self.find_col(name, force_list=True):
                 self.setas[c] = value
+        else:
+            raise IndexError(f"Failed to set setas as couldn't workout what todo with setas[{name}] = {value}")
 
     def __len__(self):
         """Return our own length."""
@@ -468,14 +470,14 @@ class setas(MutableMapping):
     #################################################################################################################
     #############################   Operator Methods ################################################################
 
-    def __add_core__(self, new, other):
+    def _add_core_(self, new, other):
         """Allow the user to add a dictionary to setas to add extra columns."""
         if not isinstance(other, dict):
             try:
                 tmp = self.clone
                 tmp(other)
                 other = tmp.to_dict()
-            except Exception:
+            except (TypeError, SyntaxError):
                 return NotImplemented
         for k, v in other.items():
             if isinstance(k, string_types) and len(k) == 1 and k in "xyzuvwdef":  # of the form x:column_name
@@ -487,20 +489,20 @@ class setas(MutableMapping):
                 k = new.find_col(k)
                 new._setas[k] = v
             else:
-                raise IndexError("Unable to workout what do with {}:{} when setting the setas attribute.".format(k, v))
+                raise IndexError(f"Unable to workout what do with {k}:{v} when setting the setas attribute.")
         return new
 
     def __add__(self, other):
         """Jump to the core."""
         new = self.clone
-        return self.__add_core__(new, other)
+        return self._add_core_(new, other)
 
     def __iadd__(self, other):
         """Jump to the core."""
         new = self
-        return self.__add_core__(new, other)
+        return self._add_core_(new, other)
 
-    def __sub_core__(self, new, other):
+    def _sub_core_(self, new, other):
         """Implement subtracting either column indices or x,y,z,d,e,f,u,v,w for the current setas."""
         if isinstance(other, string_types) and len(other) == 1 and other in "xyzuvwdef":
             while True:
@@ -509,7 +511,7 @@ class setas(MutableMapping):
                 except ValueError:
                     break
             return new
-        elif isinstance(other, index_types):
+        if isinstance(other, index_types):
             try:
                 new._setas[new.find_col(other)] = "."
                 return new
@@ -529,17 +531,17 @@ class setas(MutableMapping):
                             else:
                                 me[k] = ""
                         else:
-                            raise ValueError("{} is not set as {}".format(header, k))
+                            raise ValueError(f"{header} is not set as {k}")
                         if len(me[k]) == 0:
                             del me[k]
                 else:
-                    raise ValueError("No column is set as {}".format(k))
+                    raise ValueError(f"No column is set as {k}")
             new.clear()
             new(me)
             return new
-        elif isiterable(other):
+        if isiterable(other):
             for o in other:
-                new = self.__sub_core__(new, o)
+                new = self._sub_core_(new, o)
                 if new is NotImplemented:
                     return NotImplemented
             return new
@@ -548,12 +550,12 @@ class setas(MutableMapping):
     def __sub__(self, other):
         """Jump to the core."""
         new = self.clone
-        return self.__sub_core__(new, other)
+        return self._sub_core_(new, other)
 
     def __isub__(self, other):
         """Jump to the core."""
         new = self
-        return self.__sub_core__(new, other)
+        return self._sub_core_(new, other)
 
     def find_col(self, col, force_list=False):
         """Indexes the column headers in order to locate a column of data.shape.
@@ -582,7 +584,7 @@ class setas(MutableMapping):
         """
         if isinstance(col, int_types):  # col is an int so pass on
             if col >= len(self.column_headers):
-                raise IndexError("Attempting to index a non - existant column {}".format(col))
+                raise IndexError(f"Attempting to index a non - existant column {col}")
             if col < 0:
                 col = col % len(self.column_headers)
         elif isinstance(col, string_types):  # Ok we have a string
@@ -595,12 +597,10 @@ class setas(MutableMapping):
                 if not possible:
                     try:
                         col = int(col)
-                    except ValueError:
+                    except ValueError as err:
                         raise KeyError(
-                            'Unable to find any possible column matches for "{} in {}"'.format(
-                                col, self.column_headers
-                            )
-                        )
+                            f'Unable to find any possible column matches for "{col} in {self.column_headers}"'
+                        ) from err
                     if col < 0 or col >= self.data.shape[1]:
                         raise KeyError("Column index out of range")
                 else:
@@ -609,9 +609,8 @@ class setas(MutableMapping):
             test = col
             possible = [x for x in self.column_headers if test.search(x)]
             if not possible:
-                raise KeyError("Unable to find any possible column matches for {}".format(col.pattern))
-            else:
-                col = self.find_col(possible)
+                raise KeyError(f"Unable to find any possible column matches for {col.pattern}")
+            col = self.find_col(possible)
         elif isinstance(col, slice):
             indices = col.indices(self.shape[1])
             col = range(*indices)
@@ -619,13 +618,13 @@ class setas(MutableMapping):
         elif isiterable(col):
             col = [self.find_col(x) for x in col]
         else:
-            raise TypeError("Column index must be an integer, string, list or slice, not a {}".format(type(col)))
+            raise TypeError(f"Column index must be an integer, string, list or slice, not a {type(col)}")
         if force_list and not isinstance(col, list):
             col = [col]
         return col
 
     def clear(self):
-        """"Clear the current setas attrbute.
+        """Clear the current setas attrbute.
 
         Notes:
             Equivalent to doing :py:meth:`setas.unset` with no argument.
@@ -636,24 +635,29 @@ class setas(MutableMapping):
         """Implement a get method."""
         try:
             return self[name]
-        except (IndexError, KeyError):
+        except (IndexError, KeyError) as err:
             if default is not None:
                 return default
-            else:
-                raise KeyError("{} is not in setas and no default was given.".format(name))
+            raise KeyError(f"{name} is not in setas and no default was given.") from err
 
     def keys(self):
-        """Mapping keys are the same as iterating over the unique headers"""
+        """Acess mapping keys.
+
+        Mapping keys are the same as iterating over the unique headers"""
         for c in self._unique_headers:
             yield c
 
     def values(self):
-        """Mapping values are the same as iterating over setas."""
+        """Access mapping values.
+
+        Mapping values are the same as iterating over setas."""
         for v in self.setas:
             yield v
 
     def items(self):
-        """Mapping items iterates over keys and values."""
+        """Access mapping items.
+
+        Mapping items iterates over keys and values."""
         for k, v in zip(self._unique_headers, self.setas):
             yield k, v
 
@@ -663,13 +667,13 @@ class setas(MutableMapping):
             ret = self[name]
             self.unset(name)
             return ret
-        except (IndexError, KeyError):
+        except (IndexError, KeyError) as err:
             if default is not None:
                 return default
-            else:
-                raise KeyError("{} is not in setas and no default was given.".format(name))
+            raise KeyError(f"{name} is not in setas and no default was given.") from err
 
     def popitem(self):
+        """Return and clear a column assignment."""
         for c in "xdyezfuvw":
             if c in self:
                 v = self[c]
@@ -714,8 +718,8 @@ class setas(MutableMapping):
         else:
             try:
                 other = dict(other)
-            except (ValueError, TypeError):
-                raise TypeError("setas.update requires a dictionary not a {}".format(type(other)))
+            except (ValueError, TypeError) as err:
+                raise TypeError(f"setas.update requires a dictionary not a {type(other)}") from err
         vals = list(other.values())
         keys = list(other.keys())
         for k in "xyzuvwdef":
@@ -753,11 +757,13 @@ class setas(MutableMapping):
         return ret
 
     def to_list(self):
-        """Returns the setas attribute as a list of letter types."""
+        """Return the setas attribute as a list of letter types."""
         return list(self)
 
     def to_string(self, encode=False):
-        """"Return the setas attribute encoded as a string, optionally replacing runs of 3 or more identical characters with a precediung digit."""
+        """Return the setas attribute encoded as a string.
+
+        Optionally replaces runs of 3 or more identical characters with a precediung digit."""
         expanded = "".join(self)
         if encode:
             pat = re.compile(r"((.)\2{2,9})")
@@ -771,11 +777,12 @@ class setas(MutableMapping):
         return expanded
 
     def _get_cols(self, what=None, startx=0, no_guess=False):
-        """Uses the setas attribute to work out which columns to use for x,y,z etc.
+        """Use the setas attribute to work out which columns to use for x,y,z etc.
 
         Keyword Arguments:
             what (string): Returns either xcol, ycol, zcol, ycols,xcols rather than the full dictionary
             startx (int): Start looking for x columns at this column.
+
         Returns:
             A single integer, a list of integers or a dictionary of all columns.
         """
@@ -822,7 +829,7 @@ class setas(MutableMapping):
             elif len(columns["u"]) * len(columns["v"]) > 0:
                 axes = 5
 
-        ret = _attribute_store()
+        ret = AttributeStore()
         ret.update({"axes": axes, "xcol": xcol, "xerr": xerr})
 
         for ck, rk in {
@@ -836,10 +843,10 @@ class setas(MutableMapping):
         }.items():
             ret[rk] = columns[ck]
 
-        if axes == 0 and len(self.shape) >= 2 and self.shape[1] in self._col_defaults and not no_guess:
+        if axes == 0 and self.ndim >= 2 and self.shape[1] in self._col_defaults and not no_guess:
             ret = self._col_defaults[self.shape[1]]
         for n in ["xcol", "xerr", "ycol", "yerr", "zcol", "zerr", "ucol", "vcol", "wcol", "axes"]:
-            ret["has_{}".format(n)] = not (ret[n] is None or (isinstance(ret[n], list) and not ret[n]))
+            ret[f"has_{n}"] = not (ret[n] is None or (isinstance(ret[n], list) and not ret[n]))
 
         ret["has_uvw"] = ret["has_ucol"] & ret["has_vcol"] & ret["has_wcol"]
 
