@@ -1,23 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""
-Implement DataFile like classes to represent Instrument Manufacturer's File Formats'
-"""
+"""Implement DataFile like classes to represent Instrument Manufacturer's File Formats'."""
 __all__ = ["LSTemperatureFile", "QDFile", "RigakuFile", "SPCFile", "XRDFile"]
 
 # Standard Library imports
 from datetime import datetime
-import io
-import os
 import re
 import struct
 
 import numpy as np
 
-import Stoner.Core as Core
-from Stoner.compat import python_v3, str2bytes, bytes2str
-from Stoner.core.exceptions import StonerAssertionError, assertion, StonerLoadError
-from Stoner.core.base import string_to_type
+from .. import Core
+from ..compat import str2bytes, bytes2str
+from ..core.exceptions import StonerAssertionError, assertion, StonerLoadError
+from ..core.base import string_to_type
+from ..tools.file import FileManager, SizedFileManager
 
 
 class LSTemperatureFile(Core.DataFile):
@@ -41,13 +38,13 @@ class LSTemperatureFile(Core.DataFile):
     patterns = ["*.340"]
 
     def _load(self, filename=None, *args, **kargs):
-        """Data loader function for 340 files."""
+        """Load data for 340 files."""
         if filename is None or not filename:
             self.get_filename("r")
         else:
             self.filename = filename
 
-        with io.open(self.filename, "rb") as data:
+        with FileManager(self.filename, "rb") as data:
             keys = []
             vals = []
             for line in data:
@@ -56,10 +53,9 @@ class LSTemperatureFile(Core.DataFile):
                     break
                 parts = [p.strip() for p in line.split(":")]
                 if len(parts) != 2:
-                    raise Core.StonerLoadError("Header doesn't contain two parts at {}".format(line.strip()))
-                else:
-                    keys.append(parts[0])
-                    vals.append(parts[1])
+                    raise Core.StonerLoadError(f"Header doesn't contain two parts at {line.strip()}")
+                keys.append(parts[0])
+                vals.append(parts[1])
             else:
                 raise Core.StonerLoadError("Overan the end of the file")
             if keys != [
@@ -82,13 +78,15 @@ class LSTemperatureFile(Core.DataFile):
         return self
 
     def save(self, filename=None, **kargs):
-        """Overrides the save method to allow CSVFiles to be written out to disc (as a mininmalist output)
+        """Override the save method to allow CSVFiles to be written out to disc (as a mininmalist output).
 
         Args:
-            filename (string): Filename to save as (using the same rules as for the load routines)
+            filename (string):
+                Filename to save as (using the same rules as for the load routines)
 
         Keyword Arguments:
-            deliminator (string): Record deliniminator (defaults to a comma)
+            deliminator (string):
+                Record deliniminator (defaults to a comma)
 
         Returns:
             A copy of itself.
@@ -105,7 +103,7 @@ class LSTemperatureFile(Core.DataFile):
             cols = [self.setas.ycol[0], self.setas.xcol]
         else:
             cols = range(self.shape[1])
-        with io.open(filename, "w", errors="ignore", encoding="utf-8", newline="\r\n") as f:
+        with FileManager(filename, "w", errors="ignore", encoding="utf-8", newline="\r\n") as f:
             for k, v in (
                 ("Sensor Model", "CX-1070-SD"),
                 ("Serial Number", "Unknown"),
@@ -115,40 +113,40 @@ class LSTemperatureFile(Core.DataFile):
                 ("Number of Breakpoints", len(self)),
             ):
                 if k in ["Sensor Model", "Serial Number", "Data Format", "SetPoint Limit"]:
-                    kstr = "{:16s}".format(k + ":")
+                    kstr = f"{k+':':16s}"
                 else:
-                    kstr = "{}:   ".format(k)
+                    kstr = f"{k}:   "
                 v = self.get(k, v)
                 if k == "Data Format":
                     units = ["()", "()", "()", "()", "(Log Ohms/Kelvin)", "(Log Ohms/Log Kelvin)"]
-                    vstr = "{}      {}".format(v, units[int(v)])
+                    vstr = f"{v}      {units[int(v)]}"
                 elif k == "SetPointLimit":
-                    vstr = "{}      (Kelvin)".format(v)
+                    vstr = f"{v}      (Kelvin)"
                 elif k == "Temperature coefficient":
-                    vstr = "{} {}".format(v, ["(positive)", "(negative)"][v])
+                    vstr = f"{v} {['(positive)', '(negative)'][v]}"
                 elif k == "Number of Breakpoints":
                     vstr = str(len(self))
                 else:
                     vstr = str(v)
-                f.write(u"{}{}\n".format(kstr, vstr))
-            f.write(u"\n")
-            f.write(u"No.   ")
+                f.write(f"{kstr}{vstr}\n")
+            f.write("\n")
+            f.write("No.   ")
             for i in cols:
-                f.write(u"{:11s}".format(self.column_headers[i]))
-            f.write(u"\n\n")
+                f.write(f"{self.column_headers[i]:11s}")
+            f.write("\n\n")
             for i in range(
                 len(self.data)
             ):  # This is a slow way to write the data, but there should only ever be 200 lines
-                line = "\t".join(["{:<10.8f}".format(n) for n in self.data[i, cols]])
-                f.write(u"{}\t".format(i))
-                f.write(u"{}\n".format(line))
+                line = "\t".join([f"{n:<10.8f}" for n in self.data[i, cols]])
+                f.write(f"{i}\t")
+                f.write(f"{line}\n")
         self.filename = filename
         return self
 
 
 class QDFile(Core.DataFile):
 
-    """Extends Core.DataFile to load files from Quantum Design Systems - including PPMS, MPMS and SQUID-VSM"""
+    """Extends Core.DataFile to load files from Quantum Design Systems - including PPMS, MPMS and SQUID-VSM."""
 
     #: priority (int): is the load order for the class, smaller numbers are tried before larger numbers.
     #   .. note::
@@ -159,12 +157,14 @@ class QDFile(Core.DataFile):
     # the file load/save dialog boxes.
     patterns = ["*.dat"]  # Recognised filename patterns
 
+    mime_type = ["application/x-wine-extension-ini", "text/plain"]
+
     def _load(self, filename=None, *args, **kargs):
         """QD system file loader routine.
 
         Args:
-            filename (string or bool): File to load. If None then the existing filename is used,
-                if False, then a file dialog will be used.
+            filename (string or bool):
+                File to load. If None then the existing filename is used, if False, then a file dialog will be used.
 
         Returns:
             A copy of the itself after loading the data.
@@ -175,16 +175,16 @@ class QDFile(Core.DataFile):
             self.filename = filename
         setas = {}
         i = 0
-        with io.open(self.filename, "r", encoding="utf-8", errors="ignore") as f:  # Read filename linewise
+        with FileManager(self.filename, "r", encoding="utf-8", errors="ignore") as f:  # Read filename linewise
             for i, line in enumerate(f):
                 line = line.strip()
                 if i == 0 and line != "[Header]":
                     raise Core.StonerLoadError("Not a Quantum Design File !")
-                elif line == "[Header]" or line.startswith(";") or line == "":
+                if line == "[Header]" or line.startswith(";") or line == "":
                     continue
-                elif "[Data]" in line:
+                if "[Data]" in line:
                     break
-                elif "," not in line:
+                if "," not in line:
                     raise Core.StonerLoadError("No data in file!")
                 parts = [x.strip() for x in line.split(",")]
                 if parts[1].split(":")[0] == "SEQUENCE FILE":
@@ -194,7 +194,7 @@ class QDFile(Core.DataFile):
                     if parts[1] == "APPNAME":
                         parts[1], parts[2] = parts[2], parts[1]
                     if len(parts) > 2:
-                        key = "{}.{}".format(parts[0], parts[2])
+                        key = f"{parts[0]}.{parts[2]}"
                     else:
                         raise Core.StonerLoadError("No data in file!")
                     key = key.title()
@@ -203,12 +203,12 @@ class QDFile(Core.DataFile):
                     key = parts[0].title()
                     value = " ".join(parts[1:])
                 elif parts[0] == "FIELDGROUP":
-                    key = "{}.{}".format(parts[0], parts[1]).title()
-                    value = "[{}]".format(",".join(parts[2:]))
+                    key = f"{parts[0]}.{parts[1]}".title()
+                    value = f'[{",".join(parts[2:])}]'
                 elif parts[0] == "STARTUPAXIS":
                     axis = parts[1][0].lower()
                     setas[axis] = setas.get(axis, []) + [int(parts[2])]
-                    key = "Startupaxis-{}".format(parts[1].strip())
+                    key = f"Startupaxis-{parts[1].strip()}"
                     value = parts[2].strip()
                 else:
                     key = parts[0] + "," + parts[1]
@@ -220,10 +220,7 @@ class QDFile(Core.DataFile):
             if "Byapp" not in self:
                 raise Core.StonerLoadError("Not a Quantum Design File !")
 
-            if python_v3:
-                column_headers = f.readline().strip().split(",")
-            else:
-                column_headers = f.next().strip().split(",")
+            column_headers = f.readline().strip().split(",")
             data = np.genfromtxt([str2bytes(l) for l in f], dtype="float", delimiter=",", invalid_raise=False)
             if data.shape[0] == 0:
                 raise Core.StonerLoadError("No data in file!")
@@ -243,7 +240,7 @@ class QDFile(Core.DataFile):
 
 class RigakuFile(Core.DataFile):
 
-    """Loads a .ras file as produced by Rigaku X-ray diffractormeters"""
+    """Loads a .ras file as produced by Rigaku X-ray diffractormeters."""
 
     #: priority (int): is the load order for the class, smaller numbers are tried before larger numbers.
     #   .. note::
@@ -255,39 +252,31 @@ class RigakuFile(Core.DataFile):
     patterns = ["*.ras"]  # Recognised filename patterns
 
     def _load(self, filename=None, *args, **kargs):
-        """Reads an Rigaku ras file including handling the metadata nicely
+        """Read a Rigaku ras file including handling the metadata nicely.
 
         Args:
-            filename (string or bool): File to load. If None then the existing filename is used,
-                if False, then a file dialog will be used.
+            filename (string or bool):
+                File to load. If None then the existing filename is used, if False, then a file dialog will be used.
 
         Returns:
             A copy of the itself after loading the data.
         """
         from ast import literal_eval
 
-        pos = 0
-        reopen = False
-        filetype = io.IOBase if python_v3 else file
         if filename is None or not filename:
             self.get_filename("rb")
-        elif isinstance(filename, filetype):
-            self.filename = filename.name
-            pos = filename.tell()
-            reopen = True
         else:
             self.filename = filename
         sh = re.compile(r"^\*([^\s]+)\s+(.*)$")  # Regexp to grab the keys
         ka = re.compile(r"(.*)\-(\d+)$")
         header = dict()
         i = 0
-        with io.open(self.filename, "rb") as f:
-            f.seek(pos)
+        with SizedFileManager(self.filename, "rb") as (f, end):
             for i, line in enumerate(f):
                 line = bytes2str(line).strip()
-                if pos == 0 and (i == 0 and line != "*RAS_DATA_START"):
+                if i == 0 and not line.startswith("*RAS_"):
                     raise StonerLoadError("Not a Rigaku file!")
-                if pos != 0 or line == "*RAS_HEADER_START":
+                if line == "*RAS_HEADER_START":
                     break
             for line in f:
                 line = bytes2str(line).strip()
@@ -308,7 +297,7 @@ class RigakuFile(Core.DataFile):
                 value = header[key].strip()
                 try:
                     newvalue = literal_eval(value.strip('"'))
-                except Exception:
+                except (TypeError, ValueError, SyntaxError):
                     newvalue = literal_eval(value)
                 if newvalue == "-":
                     newvalue = np.nan  # trap for missing float value
@@ -370,23 +359,27 @@ class RigakuFile(Core.DataFile):
                         self[key] = np.array(self[key])
                 self.setas = "xy"
                 self.column_headers = column_headers
-        if reopen:
-            filename.seek(endpos)
-            self["_endpos"] = endpos
+            pos = f.tell()
+        if pos < end:  # Trap for Rigaku files with multiple scans in them.
+            self["_endpos"] = pos
+            if hasattr(filename, "seekable") and filename.seekable():
+                filename.seek(pos)
         return self
 
-    def to_Q(self, l=1.540593):
-        """Adds an additional function to covert an angualr scale to momentum transfer.
+    def to_Q(self, wavelength=1.540593):
+        """Add an additional function to covert an angualr scale to momentum transfer.
 
         Returns:
             a copy of itself.
         """
-        self.add_column((4 * np.pi / l) * np.sin(np.pi * self.column(0) / 360), header="Momentum Transfer, Q ($\\AA$)")
+        self.add_column(
+            (4 * np.pi / wavelength) * np.sin(np.pi * self.column(0) / 360), header="Momentum Transfer, Q ($\\AA$)"
+        )
 
 
 class SPCFile(Core.DataFile):
 
-    """Extends Core.DataFile to load SPC files from Raman"""
+    """Extends Core.DataFile to load SPC files from Raman."""
 
     #: priority (int): is the load order for the class, smaller numbers are tried before larger numbers.
     #   .. note::
@@ -399,6 +392,15 @@ class SPCFile(Core.DataFile):
 
     mime_type = ["application/octet-stream"]
 
+    def __init__(self, *args, **kargs):
+        """Create a few local attributes."""
+        super().__init__(*args, **kargs)
+        self._pts = None
+        self._header = None
+        self._filesize = None
+        self._xvars = None
+        self._yvars = None
+
     def _read_xdata(self, f):
         """Read the xdata from the spc file."""
         self._pts = self._header["fnpts"]
@@ -483,11 +485,11 @@ class SPCFile(Core.DataFile):
                 self._header[key] = value
 
     def _load(self, filename=None, *args, **kargs):
-        """Reads a .scf file produced by the Renishaw Raman system (amongs others)
+        """Read a .scf file produced by the Renishaw Raman system (amongs others).
 
         Args:
-            filename (string or bool): File to load. If None then the existing filename is used,
-                if False, then a file dialog will be used.
+            filename (string or bool):
+                File to load. If None then the existing filename is used, if False, then a file dialog will be used.
 
         Returns:
             A copy of the itself after loading the data.
@@ -503,8 +505,8 @@ class SPCFile(Core.DataFile):
         else:
             self.filename = filename
         # Open the file and read the main file header and unpack into a dict
-        self._filesize = os.stat(self.filename).st_size
-        with io.open(filename, "rb") as f:
+        with SizedFileManager(filename, "rb") as (f, length):
+            self._filesize = length
             spchdr = struct.unpack(b"BBBciddiBBBBi9s9sH8f30s130siiBBHf48sfifB187s", f.read(512))
             keys = (
                 "ftflgs",
@@ -625,20 +627,20 @@ class SPCFile(Core.DataFile):
                 raise Core.StonerLoadError(
                     "Filetype not implemented yet ! ftflgs={ftflgs}, fversn={fversn}".format(**self._header)
                 )
-            else:  # A single XY curve in the file.
-                # Read the xdata and add it to the file.
-                xdata = self._read_xdata(f)
-                data = np.zeros((self._pts, (n + 1)))  # initialise the data soace
-                data[:, 0] = xdata  # Put in the X-Data
-                column_headers = [self._xvars[self._header["fxtype"]]]  # And label the X column correctly
+            # Read the xdata and add it to the file.
+            xdata = self._read_xdata(f)
+            data = np.zeros((self._pts, (n + 1)))  # initialise the data soace
+            data[:, 0] = xdata  # Put in the X-Data
+            column_headers = [self._xvars[self._header["fxtype"]]]  # And label the X column correctly
 
-                # Now we're going to read the Y-data
-                data = self._read_ydata(f, data, column_headers)
-                if self._header["flogoff"] != 0:  # Ok, we've got a log, so read the log header and merge into metadata
-                    self._read_loginfo(f)
+            # Now we're going to read the Y-data
+            data = self._read_ydata(f, data, column_headers)
+            if self._header["flogoff"] != 0:  # Ok, we've got a log, so read the log header and merge into metadata
+                self._read_loginfo(f)
             # Ok now build the Stoner.Core.DataFile instance to return
             self.data = data
-            # The next bit generates the metadata. We don't just copy the metadata because we need to figure out the typehints first - hence the loop
+            # The next bit generates the metadata. We don't just copy the metadata because we need to figure out
+            # the typehints first - hence the loop
             # here to call Core.DataFile.__setitem()
             for x in self._header:
                 self[x] = self._header[x]
@@ -650,7 +652,7 @@ class SPCFile(Core.DataFile):
 
 class VSMFile(Core.DataFile):
 
-    """Extends Core.DataFile to open VSM Files"""
+    """Extends Core.DataFile to open VSM Files."""
 
     #: priority (int): is the load order for the class, smaller numbers are tried before larger numbers.
     #   .. note::
@@ -662,13 +664,16 @@ class VSMFile(Core.DataFile):
     patterns = ["*.fld"]  # Recognised filename patterns
 
     def __parse_VSM(self, header_line=3, data_line=3, header_delim=","):
-        """An intrernal function for parsing deliminated data without a leading column of metadata.copy
+        """Parsing deliminated data without a leading column of metadata.copy.
 
         Keyword Arguments:
-            header_line (int): The line in the file that contains the column headers.
-                If None, then column headers are auotmatically generated.
-            data_line (int): The line on which the data starts
-            header_delim (strong): The delimiter used for separating header values
+            header_line (int):
+                The line in the file that contains the column headers. If None, then column headers are auotmatically
+                generated.
+            data_line (int):
+                The line on which the data starts
+            header_delim (strong):
+                The delimiter used for separating header values
 
         Returns:
             Nothing, but modifies the current object.
@@ -677,11 +682,12 @@ class VSMFile(Core.DataFile):
             The default values are configured fir read VSM data files
         """
         try:
-            with io.open(self.filename, errors="ignore", encoding="utf-8") as f:
+            with FileManager(self.filename, errors="ignore", encoding="utf-8") as f:
                 for i, line in enumerate(f):
                     if i == 0:
-                        self["Timestamp"] = line.strip()
-                        check = datetime.strptime(self["Timestamp"], "%a %b %d %H:%M:%S %Y")
+                        first = line.strip()
+                        self["Timestamp"] = first
+                        check = datetime.strptime(first, "%a %b %d %H:%M:%S %Y")
                         if check is None:
                             raise Core.StonerLoadError("Not a VSM file ?")
                     elif i == 1:
@@ -691,13 +697,13 @@ class VSMFile(Core.DataFile):
                     elif i == header_line:
                         unit_string = line.strip()
                         column_headers = [
-                            "{} ({})".format(h.strip(), u.strip())
+                            f"{h.strip()} ({u.strip()})"
                             for h, u in zip(header_string.split(header_delim), unit_string.split(header_delim))
                         ]
                     elif i > 3:
                         break
-        except (StonerAssertionError, ValueError, AssertionError, TypeError) as e:
-            raise Core.StonerLoadError("Not a VSM File" + str(e.args))
+        except (StonerAssertionError, ValueError, AssertionError, TypeError) as err:
+            raise Core.StonerLoadError(f"Not a VSM File {err}") from err
         self.data = np.genfromtxt(
             self.filename,
             dtype="float",
@@ -717,8 +723,8 @@ class VSMFile(Core.DataFile):
         """VSM file loader routine.
 
         Args:
-            filename (string or bool): File to load. If None then the existing filename is used,
-                if False, then a file dialog will be used.
+            filename (string or bool):
+                File to load. If None then the existing filename is used, if False, then a file dialog will be used.
 
         Returns:
             A copy of the itself after loading the data.
@@ -733,7 +739,7 @@ class VSMFile(Core.DataFile):
 
 class XRDFile(Core.DataFile):
 
-    """Loads Files from a Brucker D8 Discovery X-Ray Diffractometer"""
+    """Loads Files from a Brucker D8 Discovery X-Ray Diffractometer."""
 
     #: priority (int): is the load order for the class, smaller numbers are tried before larger numbers.
     #   .. note::
@@ -744,17 +750,19 @@ class XRDFile(Core.DataFile):
     # the file load/save dialog boxes.
     patterns = ["*.dql"]  # Recognised filename patterns
 
+    mime_type = ["application/x-wine-extension-ini", "text/plain"]
+
     def __init__(self, *args, **kargs):
         """Add a public attribute to XRD File."""
-        super(XRDFile, self).__init__(*args, **kargs)
+        super().__init__(*args, **kargs)
         self._public_attrs = {"four_bounce": bool}
 
     def _load(self, filename=None, *args, **kargs):
-        """Reads an XRD Core.DataFile as produced by the Brucker diffractometer
+        """Read an XRD Core.DataFile as produced by the Brucker diffractometer.
 
         Args:
-            filename (string or bool): File to load. If None then the existing filename is used,
-                if False, then a file dialog will be used.
+            filename (string or bool):
+                File to load. If None then the existing filename is used, if False, then a file dialog will be used.
 
         Returns:
             A copy of the itself after loading the data.
@@ -768,7 +776,7 @@ class XRDFile(Core.DataFile):
         else:
             self.filename = filename
         sh = re.compile(r"\[(.+)\]")  # Regexp to grab section name
-        with io.open(self.filename, errors="ignore", encoding="utf-8") as f:  # Read filename linewise
+        with FileManager(self.filename, errors="ignore", encoding="utf-8") as f:  # Read filename linewise
             if f.readline().strip() != ";RAW4.00":  # Check we have the corrrect fileformat
                 raise Core.StonerLoadError("File Format Not Recognized !")
             drive = 0
@@ -780,16 +788,13 @@ class XRDFile(Core.DataFile):
                         section = section + str(drive)
                         drive = drive + 1
                     elif section == "Data":  # Data section contains the business but has a redundant first line
-                        if python_v3:
-                            f.readline()
-                        else:
-                            f.next()
+                        f.readline()
                     for line in f:  # Now start reading lines in this section...
-                        if (
-                            line.strip() == ""
-                        ):  # A blank line marks the end of the section, so go back to the outer loop which will handle a new section
+                        if line.strip() == "":
+                            # A blank line marks the end of the section, so go back to the outer loop which will
+                            # handle a new section
                             break
-                        elif section == "Data":  # In the Data section read lines of data value,vale
+                        if section == "Data":  # In the Data section read lines of data value,vale
                             parts = line.split(",")
                             angle = parts[0].strip()
                             counts = parts[1].strip()
@@ -799,7 +804,8 @@ class XRDFile(Core.DataFile):
                             parts = line.split("=")
                             key = parts[0].strip()
                             data = parts[1].strip()
-                            # Keynames in main metadata are section:key - use theCore.DataFile magic to do type determination
+                            # Keynames in main metadata are section:key - use theCore.DataFile magic to do type
+                            # determination
                             self[section + ":" + key] = string_to_type(data)
             column_headers = ["Angle", "Counts"]  # Assume the columns were Angles and Counts
 
@@ -812,7 +818,7 @@ class XRDFile(Core.DataFile):
         return self
 
     def to_Q(self, l=1.540593):
-        """Adds an additional function to covert an angualr scale to momentum transfer
+        """Add an additional function to covert an angualr scale to momentum transfer.
 
         returns a copy of itself.
         """
