@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Plot Templates module - contains classes that style plots produced by :class:`.Data`
-"""
+"""Plot Templates module - contains classes that style plots produced by :class:`.Data`."""
 
 __all__ = [
     "TexFormatter",
@@ -13,13 +12,15 @@ __all__ = [
     "SketchPlot",
     "SeabornPlotStyle",
 ]
+from os.path import join, dirname, realpath, exists
+from inspect import getfile
+from collections.abc import MutableMapping, Mapping
+
 import matplotlib.pyplot as plt
 from matplotlib.ticker import EngFormatter, Formatter
 from matplotlib.ticker import AutoLocator
-from os.path import join, dirname, realpath, exists
+import numpy as np
 from numpy.random import normal
-from inspect import getfile
-from collections import MutableMapping, Mapping
 
 try:
     import seaborn as sns
@@ -28,21 +29,19 @@ try:
 except ImportError:
     SEABORN = False
 
-import numpy as _np_
-
 
 def _round(value, offset=2):
-    """Provate method to round numbers for the TexFormatters to avoid crazy numbers of decimal places"""
+    """Round numbers for the TexFormatters to avoid crazy numbers of decimal places."""
     for i in range(5):
-        vt = _np_.round(value, i)
-        if _np_.abs(value - vt) < 10 ** (-i - offset):
+        vt = np.round(value, i)
+        if np.abs(value - vt) < 10 ** (-i - offset):
             value = vt
             break
     return value
 
 
 def _add_dots(key):
-    """replace __ with . in key."""
+    """Replace __ with . in key."""
     return key.replace("__", ".").replace("..", "__")
 
 
@@ -52,35 +51,35 @@ def _remove_dots(key):
 
 class TexFormatter(Formatter):
 
-    """An axis tick label formatter that emits Tex formula mode code.
+    r"""An axis tick label formatter that emits Tex formula mode code.
 
-    Formating is set so that large numbers are registered as \\times 10^{power}
+    Formating is set so that large numbers are registered as :math`\times 10^{power}`
     rather than using E notation."""
 
     def __call__(self, value, pos=None):
-        """Return the value ina  suitable texable format"""
-        if value is None or _np_.isnan(value):
+        """Return the value ina  suitable texable format."""
+        if value is None or np.isnan(value):
             ret = ""
         elif value != 0.0:
-            power = _np_.floor(_np_.log10(_np_.abs(value)))
-            if _np_.abs(power) < 4:
-                ret = "${}$".format(_round(value))
+            power = np.floor(np.log10(np.abs(value)))
+            if np.abs(power) < 4:
+                ret = f"${round(value)}$"
             else:
                 v = _round(value / (10 ** power))
-                ret = "${}\\times 10^{{{:.0f}}}$".format(v, power)
+                ret = f"${v}\\times 10^{{{power:.0f}}}$"
         else:
             ret = "$0.0$"
         return ret
 
     def format_data(self, value):
-        """Returns the full string representation of the value with the position unspecified."""
+        """Return the full string representation of the value with the position unspecified."""
         return self.__call__(value)
 
     def format_data_short(self, value):  # pylint: disable=r0201
         """Return a short string version of the tick value.
 
         Defaults to the position-independent long value."""
-        return "{:g}".format(value)
+        return f"{value:g}"
 
 
 class TexEngFormatter(EngFormatter):
@@ -92,6 +91,7 @@ class TexEngFormatter(EngFormatter):
     """
 
     prefix = {
+        0: "",
         3: "k",
         6: "M",
         9: "G",
@@ -111,31 +111,38 @@ class TexEngFormatter(EngFormatter):
     }
 
     def __call__(self, value, pos=None):
-        """Return the value ina  suitable texable format"""
-        if value is None or _np_.isnan(value):
+        """Return the value ina  suitable texable format."""
+        if value is None or np.isnan(value):
             ret = ""
         elif value != 0.0:
-            power = _np_.floor(_np_.log10(_np_.abs(value)))
-            pre = _np_.ceil(power / 3.0) * 3
-            power = power % 3
-            if pre == 0:
-                ret = "${}\\,\\mathrm{{{}}}$".format(_round(value, 4), self.unit)
+            power = np.floor(np.log10(np.abs(value)))
+            pre = np.ceil(power / 3.0) * 3
+            if -1 <= power <= 3 or pre == 0:
+                ret = f"${round(value, 4)}\\,\\mathrm{{{self.unit}}}$"
             else:
+                power = power % 3
                 v = _round(value / (10 ** pre), 4)
-                ret = "${}\\mathrm{{{} {}}}$".format(v, self.prefix[int(pre)], self.unit)
+                if np.abs(v) < 0.1:
+                    v *= 1000
+                    pre -= 3
+                elif np.abs(v) > 1000.0:
+                    v /= 1000
+                    pre += 3.0
+
+                ret = f"${v}\\mathrm{{{self.prefix[int(pre)]} {self.unit}}}$"
         else:
             ret = "$0.0$"
         return ret
 
     def format_data(self, value):
-        """Returns the full string representation of the value with the position unspecified."""
+        """Return the full string representation of the value with the position unspecified."""
         return self.__call__(value)
 
     def format_data_short(self, value):  # pylint: disable=r0201
         """Return a short string version of the tick value.
 
         Defaults to the position-independent long value."""
-        return "{:g}".format(value)
+        return f"{value:g}"
 
 
 class DefaultPlotStyle(MutableMapping):
@@ -167,21 +174,23 @@ class DefaultPlotStyle(MutableMapping):
     # Internal class attributes.
     _inches_per_pt = 1.0 / 72.27  # Convert pt to inch
     _mm_per_inch = 25.4
-    _golden_mean = (_np_.sqrt(5) - 1.0) / 2.0  # Aesthetic ratio
+    _golden_mean = (np.sqrt(5) - 1.0) / 2.0  # Aesthetic ratio
 
     # Settings for this figure type. All instance attributes which start template_
     # will be used. Once the leading template_ is stripped, all _ characters are replaced
     # with . and then the attributes are mapped to a dictionary and used to update the rcParams
     # dictionary
 
+    # pylint: disable=attribute-defined-outside-init
+
     show_xlabel = True
     show_ylabel = True
     show_zlabel = True
     show_title = True
     show_legend = True
-    xformatter = TexFormatter
-    yformatter = TexFormatter
-    zformatter = TexFormatter
+    xformatter = TexEngFormatter
+    yformatter = TexEngFormatter
+    zformatter = TexEngFormatter
     xlocater = AutoLocator
     ylocater = AutoLocator
     zlocater = AutoLocator
@@ -216,15 +225,18 @@ class DefaultPlotStyle(MutableMapping):
         which will be used to upodate the rcParams first.
         """
         self._stylesheet = None
+        # self.fig_width = None
+        # self.fig_height = None
+
         self.update(**kargs)
 
     def __call__(self, **kargs):
-        """Calling the template object can manipulate the rcParams that will be set."""
+        """Call the template object can manipulate the rcParams that will be set."""
         for k, v in kargs.items():
             if k.startswith("template_"):
                 nk = _add_dots(k[:9])
                 if nk in plt.rcParams:
-                    super(DefaultPlotStyle, self).__setattr__(nk, v)
+                    super().__setattr__(nk, v)
                     self[nk] = v
             else:
                 self.update({_add_dots(k): v})
@@ -232,16 +244,16 @@ class DefaultPlotStyle(MutableMapping):
     def __delitem__(self, name):
         """Clear any setting that overides the default for *name*."""
         if hasattr(self, name):
-            default = getattr(self.__class__(), name)
+            default = getattr(type(self)(), name)
             setattr(self, name, default)
         elif name in plt.rcParams:
             params = dict(plt.rcParams)
             del params[name]
             plt.rcdefaults()
             plt.rcParams.update(params)
-            super(DefaultPlotStyle, self).__delattr__(_remove_dots("template_{}".format(name)))
+            super().__delattr__(_remove_dots(f"template_{name}"))
         else:
-            raise KeyError("{} is not recognised as part of the template".format(name))
+            raise KeyError(f"{name} is not recognised as part of the template")
 
     def __getattr__(self, name):
         """Provide magic to read certain attributes of the template."""
@@ -249,12 +261,10 @@ class DefaultPlotStyle(MutableMapping):
             attrname = _add_dots(name[9:])
             if attrname in plt.rcParams:
                 return plt.rcParams[attrname]
-            else:
-                raise AttributeError("template attribute not in rcParams")
-        elif name == "showlegend":
+            raise AttributeError("template attribute not in rcParams")
+        if name == "showlegend":
             return self.show_legend and len(plt.gca().get_legend_handles_labels()[1]) > 1
-        else:
-            return super(DefaultPlotStyle, self).__getattribute__(name)
+        return super().__getattribute__(name)
 
     def __getitem__(self, name):
         """Try to match *name* to a style setting."""
@@ -264,8 +274,7 @@ class DefaultPlotStyle(MutableMapping):
             pass
         if name in plt.rcParams:
             return plt.rcParams[name]
-        else:
-            raise KeyError("{} is not recognised as part of the template".format(name))
+        raise KeyError(f"{name} is not recognised as part of the template")
 
     def __iter__(self):
         """Iterate over stylesjeet settings."""
@@ -286,9 +295,9 @@ class DefaultPlotStyle(MutableMapping):
         if name.startswith("template_"):
             attrname = _add_dots(name[9:])
             plt.rcParams[attrname] = value
-            super(DefaultPlotStyle, self).__setattr__(name, value)
+            super().__setattr__(name, value)
         else:
-            super(DefaultPlotStyle, self).__setattr__(name, value)
+            super().__setattr__(name, value)
 
     def __setitem__(self, name, value):
         """Set a stylesheet setting by *name*."""
@@ -297,12 +306,13 @@ class DefaultPlotStyle(MutableMapping):
         else:
             if name in plt.rcParams:
                 plt.rcParams[name] = value
-                name = _remove_dots("template_{}".format(name))
-                super(DefaultPlotStyle, self).__setattr__(name, value)
+                name = _remove_dots(f"template_{name}")
+                super().__setattr__(name, value)
             else:
-                raise KeyError("{} is not recognised as part of the template".format(name))
+                raise KeyError(f"{name} is not recognised as part of the template")
 
     def _allowed_attr(self, x, template=False):
+        """Private method to test if this is a template attribute we can set."""
         return (
             not x.startswith("_")
             and (not template) ^ x.startswith("template_")
@@ -321,7 +331,7 @@ class DefaultPlotStyle(MutableMapping):
         sheets = []
         classes = []
         for c in levels:  # Iterate through all possible parent classes and build a list of stylesheets
-            if c is self.__class__ or c in classes or not isinstance(c, DefaultPlotStyle):
+            if c is type(self) or c in classes or not isinstance(c, DefaultPlotStyle):
                 continue
             for f in [
                 join(realpath(dirname(getfile(c))), c.stylename + ".mplstyle"),
@@ -337,8 +347,8 @@ class DefaultPlotStyle(MutableMapping):
             classes.append(c)  # Stop double visiting files
         # Now do the same for this class, but allow the stylename to be an instance variable as well
         for f in [
-            join(dirname(realpath(getfile(self.__class__))), self.stylename + ".mplstyle"),
-            join(dirname(realpath(getfile(self.__class__))), "stylelib", self.stylename + ".mplstyle"),
+            join(dirname(realpath(getfile(type(self)))), self.stylename + ".mplstyle"),
+            join(dirname(realpath(getfile(type(self)))), "stylelib", self.stylename + ".mplstyle"),
         ]:
             if exists(f):
                 sheets.append(f)
@@ -356,9 +366,9 @@ class DefaultPlotStyle(MutableMapping):
         raise AttributeError("Can't set the stylesheet value, this is dervied from the stylename aatribute.")
 
     def clear(self):
-        """Custom clear method that resets everything back o defaults."""
+        """Reset everything back o defaults."""
         attrs = [x for x in dir(self) if self._allowed_attr(x)]
-        defaults = self.__class__()
+        defaults = type(self)()
         for attr in attrs:
             setattr(self, attr, getattr(defaults, attr))
         plt.rcdefaults()
@@ -366,7 +376,7 @@ class DefaultPlotStyle(MutableMapping):
         for attr in attrs:
             delattr(self, attr)
 
-    def update(self, *args, **kargs):
+    def update(self, *args, **kargs):  # pylint: disable=signature-differs
         """Update the template with new attributes from keyword arguments.
 
         Up to one positional argument may be supplied
@@ -375,7 +385,7 @@ class DefaultPlotStyle(MutableMapping):
         may be specified, with .'s replaced with _ and )_ replaced with __.
         """
         if len(args) == 1 and isinstance(args[0], Mapping):
-            super(DefaultPlotStyle, self).update(args[0])
+            super().update(args[0])
         elif len(args) > 0:
             raise SyntaxError(
                 "Only one posotional argument which should be a Mapping subclass can be supplied toi update."
@@ -387,7 +397,9 @@ class DefaultPlotStyle(MutableMapping):
                 self.__setattr__("template_" + k, kargs[k])
 
     def new_figure(self, figure=False, **kargs):
-        """This is called by PlotMixin to setup a new figure before we do anything."""
+        """Create a new figure.
+
+        This is called by PlotMixin to setup a new figure before we do anything."""
         plt.rcdefaults()  # Start by resetting to our default settings
         params = dict()
         self.apply()
@@ -407,7 +419,7 @@ class DefaultPlotStyle(MutableMapping):
                     params[attrname] = value
         plt.rcParams.update(params)  # Apply these parameters
         projection = kargs.pop("projection", "rectilinear")
-        self.template_figure__figsize = kargs.pop("figsize", self.template_figure__figsize)
+        self.template_figure__figsize = kargs.pop("figsize", self.template_figure__figsize)  # pylint: disable=W0201
         if "ax" in kargs:  # Giving an axis instance in kargs means we can use that as out figure
             ax = kargs.get("ax")
             plt.sca(ax)
@@ -417,7 +429,7 @@ class DefaultPlotStyle(MutableMapping):
         elif figure is not None:
             fig = plt.figure(figure, figsize=self.template_figure__figsize)
             if len(fig.axes) == 0:
-                rect = [plt.rcParams["figure.subplot.{}".format(i)] for i in ["left", "bottom", "right", "top"]]
+                rect = [plt.rcParams[f"figure.subplot.{i}"] for i in ["left", "bottom", "right", "top"]]
                 rect[2] = rect[2] - rect[0]
                 rect[3] = rect[3] - rect[1]
                 if projection == "3d":
@@ -426,7 +438,14 @@ class DefaultPlotStyle(MutableMapping):
                     ax = fig.add_axes(rect)
             else:
                 if projection == "3d":
-                    ax = kargs.pop("ax", fig.gca(projection="3d"))
+                    if "ax" in kargs:
+                        ax = kargs.pop("ax")
+                    else:
+                        for ax in plt.gcf().axes:
+                            if "zaxis" in ax.properties():
+                                break
+                        else:
+                            ax = plt.axes(projection="3d")
                 else:
                     ax = kargs.pop("ax", fig.gca())
 
@@ -440,7 +459,7 @@ class DefaultPlotStyle(MutableMapping):
         return ret, ax
 
     def apply(self):
-        """Scan for all attributes that start template_ and build them into a dictionary to update matplotlib settings with."""
+        """Update matplotlib rc parameters from any attributes starting template_."""
         plt.style.use(self.stylesheet)
         for attr in dir(self):
             v = getattr(self, attr)
@@ -453,18 +472,18 @@ class DefaultPlotStyle(MutableMapping):
         self.customise()
 
     def customise(self):
-        """Hook to customise plot.
+        """Implement hook to customise plot.
 
         This method is supplied for sub classes to override to provide additional
         plot customisation after the rc paramaters are updated from the class and
         instance attributes."""
-        pass
 
     def customise_axes(self, ax, plot):
-        """This method is run when we have an axis to manipulate.
+        """Implement hook for for when we have an axis to manipulate.
 
         Args:
-            ax (matplotlib axes): The axes to be modified by this function.
+            ax (matplotlib axes):
+                The axes to be modified by this function.
 
         Note:
             In the DefaultPlotStyle class this method is used to set SI units
@@ -494,9 +513,12 @@ class DefaultPlotStyle(MutableMapping):
         """Call all the routines necessary to annotate the axes etc.
 
         Args:
-            ix(integer): Index of current subplot
-            multiple (string): how to handle multiple subplots
-            plot (Stoner.plot.PlotMixin): The PlotMixin boject we're working with
+            ix(integer):
+                Index of current subplot
+            multiple (string):
+                how to handle multiple subplots
+            plot (Stoner.plot.PlotMixin):
+                The PlotMixin boject we're working with
         """
         if multiple in self.subplot_settings:
             if ix == 0:
@@ -530,12 +552,10 @@ class GBPlotStyle(DefaultPlotStyle):
     This is largely an experimental class for trying things out rather than
     for serious plotting.
 
-    Example
+    Example:
         .. plot:: samples/plotstyles/GBStyle.py
             :include-source:
             :outname: gbstyle
-
-
     """
 
     xformatter = TexEngFormatter
@@ -543,8 +563,8 @@ class GBPlotStyle(DefaultPlotStyle):
     stylename = "GBStyle"
 
     def customise_axes(self, ax, plot):
-        """Override the default axis configuration"""
-        super(GBPlotStyle, self).customise_axes(ax, plot)
+        """Override the default axis configuration."""
+        super().customise_axes(ax, plot)
         ax.spines["top"].set_visible(False)
         ax.spines["right"].set_visible(False)
         ax.xaxis.set_ticks_position("bottom")
@@ -558,19 +578,17 @@ class JTBPlotStyle(DefaultPlotStyle):
 
     """Template class for Joe's Plot settings.
 
-    Example
+    Example:
         .. plot:: samples/plotstyles/JTBStyle.py
             :include-source:
             :outname: jtbstyle
-
     """
 
     show_title = False
     stylename = "JTB"
 
     def customise_axes(self, ax, plot):
-        """Override the default axis configuration (or not)"""
-        pass
+        """Override the default axis configuration (or not)."""
 
 
 class JTBinsetStyle(DefaultPlotStyle):
@@ -581,8 +599,7 @@ class JTBinsetStyle(DefaultPlotStyle):
     stylename = "JTBinset"
 
     def customise_axes(self, ax, plot):
-        """Override the default axis configuration (or not)"""
-        pass
+        """Override the default axis configuration (or not)."""
 
 
 class ThesisPlotStyle(DefaultPlotStyle):
@@ -597,7 +614,7 @@ class PRBPlotStyle(DefaultPlotStyle):
 
     """A figure Style for making figures for Phys Rev * Jounrals.
 
-    Example
+    Example:
         .. plot:: samples/plotstyles/PRBStyle.py
             :include-source:
             :outname: prbstyle
@@ -618,12 +635,10 @@ class SketchPlot(DefaultPlotStyle):
     Implemented as a bit of a joke, but perhaps someone will use this in a real
     presentation one day ?
 
-    Example
+    Example:
         .. plot:: samples/plotstyles/SketchStyle.py
             :include-source:
             :outname: sketchstyle
-
-
     """
 
     stylename = "sketch"
@@ -633,8 +648,8 @@ class SketchPlot(DefaultPlotStyle):
         plt.xkcd()
 
     def customise_axes(self, ax, plot):
-        """Override the default axis configuration"""
-        super(SketchPlot, self).customise_axes(ax, plot)
+        """Override the default axis configuration."""
+        super().customise_axes(ax, plot)
         ax.spines["top"].set_visible(False)
         if len(plot.axes) > 1 and plot.multiple == "y2":
             pass
@@ -661,11 +676,14 @@ if SEABORN:  # extra classes if we have seaborn available
         """A plotdtyle that makes use of the seaborn plotting package to make visually attractive plots.
 
         Attributes:
-            stylename (str): The seaborn plot stlye to use - darkgrid, whitegrid, dark, white, or ticks
-            context (str): The seaborn plot context for scaling elements - paper,notebook,talk, or poster
-            palette (str): A name of a predefined seaborn palette.
+            stylename (str):
+                The seaborn plot stlye to use - darkgrid, whitegrid, dark, white, or ticks
+            context (str):
+                The seaborn plot context for scaling elements - paper,notebook,talk, or poster
+            palette (str):
+                A name of a predefined seaborn palette.
 
-        Example
+        Example:
             .. plot:: samples/plotstyles/SeabornStyle.py
                 :include-source:
                 :outname: seabornstyle
@@ -696,12 +714,9 @@ if SEABORN:  # extra classes if we have seaborn available
         @palette.setter
         def palette(self, name):
             """Force palette to take allowed values."""
-            try:
-                with sns.color_palette(name):
-                    pass
-                self._palette = name
-            except Exception as e:
-                raise e
+            with sns.color_palette(name):
+                pass
+            self._palette = name
 
         @property
         def stylename(self):
