@@ -1,24 +1,24 @@
 """Example of nDimArrhenius Fit."""
-from Stoner import Data
-import Stoner.Fit as SF
+# pylint: disable=invalid-name
 from numpy import linspace, ones_like
 from numpy.random import normal
 
+from Stoner import Data
+from Stoner.analysis.fitting.models.tunnelling import BDR, bdr
+
 # Make some data
 V = linspace(-10, 10, 1000)
-I = SF.bdr(V, 2.5, 3.2, 0.3, 15.0, 1.0) + normal(size=len(V), scale=1.0e-3)
+I = bdr(V, 2.5, 3.2, 0.3, 15.0, 1.0) + normal(size=len(V), scale=1.0e-3)
 dI = ones_like(V) * 1.0e-3
 
 # Curve fit
 d = Data(V, I, dI, setas="xye", column_headers=["Bias", "Current", "Noise"])
 
-d.curve_fit(
-    SF.bdr, p0=[2.5, 3.2, 0.3, 15.0, 1.0], result=True, header="curve_fit"
-)
+d.curve_fit(bdr, p0=[2.5, 3.2, 0.3, 15.0, 1.0], result=True, header="curve_fit")
 d.setas = "xyey"
 d.plot(fmt=["r.", "b-"])
 d.annotate_fit(
-    SF.bdr,
+    bdr,
     x=0.6,
     y=0.05,
     prefix="bdr",
@@ -27,7 +27,7 @@ d.annotate_fit(
 
 # lmfit
 d.setas = "xy"
-fit = SF.BDR(missing="drop")
+fit = BDR(missing="drop")
 p0 = fit.guess(I, x=V)
 for p, v, mi, mx in zip(
     ["A", "phi", "dphi", "d", "mass"],
