@@ -1,13 +1,15 @@
 """Example of Quadratic Fit."""
-from Stoner import Data
-import Stoner.Fit as SF
+# pylint: disable=invalid-name
 from numpy import linspace
 from numpy.random import normal
 import matplotlib.pyplot as plt
 
+from Stoner import Data
+from Stoner.analysis.fitting.models.generic import quadratic, Quadratic
+
 # Make some data
 x = linspace(-10, 10, 101)
-y = SF.quadratic(x + normal(size=len(x), scale=0.1), 4, -2, 11) * normal(
+y = quadratic(x + normal(size=len(x), scale=0.1), 4, -2, 11) * normal(
     size=len(x), scale=0.05, loc=1.0
 )
 s = y * 0.05
@@ -25,11 +27,11 @@ d.text(
 )
 
 d.setas = "xy"
-d.curve_fit(SF.quadratic, result=True, header="Curve-fit")
+d.curve_fit(quadratic, result=True, header="Curve-fit")
 d.setas = "x...y"
 d.plot(fmt="b-", label="curve-fit")
 d.annotate_fit(
-    SF.quadratic,
+    quadratic,
     prefix="quadratic",
     x=0.2,
     y=0.65,
@@ -37,19 +39,19 @@ d.annotate_fit(
 )
 
 d.setas = "xy"
-fit = SF.Quadratic()
+fit = Quadratic()
 p0 = fit.guess(y, x=x)
-d.lmfit(SF.Quadratic, p0=p0, result=True, header="lmfit")
+d.lmfit(Quadratic, p0=p0, result=True, header="lmfit")
 
 d.setas = "x...y"
 d.plot(fmt="g-", label="lmfit")
 d.annotate_fit(
-    SF.Quadratic,
+    Quadratic,
     prefix="Quadratic",
     x=0.65,
     y=0.65,
     fontdict={"size": "x-small", "color": "green"},
 )
-
+d.ylim(0, 500)
 d.title = "Qudratic Fitting"
 plt.legend(loc=4)
