@@ -1,15 +1,20 @@
 """Test Weak-localisation fitting."""
-from Stoner import Data
-import Stoner.Fit as SF
-from Stoner.plot.formats import TexEngFormatter
+# pylint: disable=invalid-name
+from copy import copy
 
 from numpy import linspace, ones_like
 from numpy.random import normal
-from copy import copy
+
+from Stoner import Data
+from Stoner.analysis.fitting.models.magnetism import (
+    KittelEquation,
+    kittelEquation,
+)
+from Stoner.plot.formats import TexEngFormatter
 
 B = linspace(1e3, 5e4, 51)
 params = [2.2, 1e5, 2e2]
-G = SF.kittelEquation(B, *params) + normal(size=len(B), scale=5e7)
+G = kittelEquation(B, *params) + normal(size=len(B), scale=5e7)
 dG = ones_like(B) * 5e7
 
 d = Data(
@@ -20,9 +25,9 @@ d = Data(
     column_headers=["Field $Oe$", r"$\nu (Hz)$", r"\delta $\nu (Hz)$"],
 )
 
-d.curve_fit(SF.kittelEquation, p0=copy(params), result=True, header="curve_fit")
+d.curve_fit(kittelEquation, p0=copy(params), result=True, header="curve_fit")
 
-fit = SF.KittelEquation()
+fit = KittelEquation()
 p0 = fit.guess(G, x=B)
 
 d.lmfit(fit, p0=p0, result=True, header="lmfit")
@@ -31,14 +36,14 @@ d.setas = "xyeyy"
 d.plot(fmt=["r.", "b-", "g-"])
 
 d.annotate_fit(
-    SF.kittelEquation,
+    kittelEquation,
     x=0.5,
     y=0.25,
     fontdict={"size": "x-small", "color": "blue"},
     mode="eng",
 )
 d.annotate_fit(
-    SF.KittelEquation,
+    KittelEquation,
     x=0.5,
     y=0.05,
     fontdict={"size": "x-small", "color": "green"},
