@@ -1,9 +1,11 @@
 """Simple use of lmfit to fit data."""
-from Stoner import Data
-from Stoner.Fit import PowerLaw
-from Stoner.analysis.fitting import odr_Model
+# pylint: disable=invalid-name
 from numpy import linspace, random
 
+from Stoner import Data
+from Stoner.analysis.fitting.models.generic import PowerLaw
+from Stoner.analysis.fitting import odr_Model
+
 # Make some data
 x = linspace(0, 10.0, 101)
 y = PowerLaw().func(x, 1e-1, 1.64) * random.normal(
