@@ -1,7 +1,9 @@
-"""Decompose Example"""
+"""Decompose Into symmetric and antisymmetric parts example."""
+# pylint: disable=invalid-name
+from numpy import linspace, reshape, array
+
 from Stoner import Data
 from Stoner.tools import format_val
-from numpy import linspace, reshape, array
 
 x = linspace(-10, 10, 201)
 y = 0.3 * x ** 3 - 6 * x ** 2 + 11 * x - 20
@@ -9,7 +11,7 @@ d = Data(x, y, setas="xy", column_headers=["X", "Y"])
 d.decompose()
 d.setas = "xyyy"
 coeffs = d.polyfit(polynomial_order=3)
-str_coeffs = [format_val(c, mode="eng") for c in coeffs.ravel()]
+str_coeffs = [format_val(c, mode="eng", places=1) for c in coeffs.ravel()]
 str_coeffs = reshape(array(str_coeffs), coeffs.shape)
 d.plot()
 d.text(
