@@ -1,7 +1,9 @@
 """Detect outlying points from a lione."""
+# pylint: disable=invalid-name
+import numpy as np
+
 from Stoner import Data
 from Stoner.analysis.utils import poly_outlier
-import numpy as np
 
 x = np.linspace(0, 100, 201)
 y = 0.01 * x ** 2 + 5 * np.sin(x / 10.0)
@@ -14,6 +16,9 @@ d.plot(fmt="b.", label="raw data")
 e = d.clone
 e.outlier_detection(window=5, action="delete")
 e.plot(fmt="r-", label="Default Outliers removed")
+h = d.clone
+h.outlier_detection(window=3, action="delete", shape="hanning")
+h.plot(color="orange", label="Default Outliers removed with Hanning window")
 f = d.clone
 f.outlier_detection(
     window=21, order=3, certainty=2, width=3, action="delete", func=poly_outlier
