@@ -1,10 +1,12 @@
-"""Example of using scale to overlap data"""
-from Stoner import Data
+"""Example of using scale to overlap data."""
+# pylint: disable=invalid-name, no-member
 from numpy import linspace, sin, exp, pi, column_stack
 from numpy.random import normal
 import matplotlib as mpl
 from tabulate import tabulate
 
+from Stoner import Data
+
 mpl.rc("text", usetex=True)
 
 x = linspace(0, 10 * pi, 201)
