@@ -10,6 +10,7 @@ import sys
 import pathlib
 import io
 import urllib
+import os
 
 from Stoner import Data,__homepath__, __datapath__, ImageFile
 from Stoner.Core import DataFile
@@ -48,9 +49,9 @@ def list_files():
 
     return sorted(incfiles)
 
+listed_files=list_files()
 
-
-@pytest.mark.parametrize("filename", list_files(),ids=[x.name for x in list_files()])
+@pytest.mark.parametrize("filename", listed_files)
 def test_one_file(tmpdir, filename):
     loaded=Data(filename,debug=False)
     assert isinstance(loaded,DataFile),f"Failed to load {filename.name} correctly."
